@@ -6,6 +6,7 @@ use warnings;
 
 # Modules.
 use Class::Utils qw(set_params);
+use Encode qw(decode);
 use Error::Pure qw(err);
 use Readonly;
 
@@ -13,7 +14,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -34,6 +35,9 @@ sub new {
 		'other' => undef,
 	},
 
+	# Input encoding.
+	$self->{'input_encoding'} = 'utf-8';
+
 	# Non parser options.
 	$self->{'non_parser_options'} = {};
 
@@ -128,6 +132,7 @@ sub parse_handler {
 # Parse text string.
 sub _parse {
 	my ($self, $line, $out) = @_;
+	$line = decode($self->{'input_encoding'}, $line);
 	$self->{'_line'} = $line;
 	my ($type, $value) = $line =~ m/\A([A()\?\-_])(.*)\Z/;
 	if (! $type) {
@@ -284,6 +289,11 @@ PYX::Parser - PYX parser with callbacks.
 
 =back
 
+=item * C<input_encoding>
+
+ Input encoding.
+ Default value is 'utf-8'.
+
 =item * C<non_parser_options>
 
  Non parser options.
@@ -394,7 +404,9 @@ PYX::Parser - PYX parser with callbacks.
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
-L<Error::Pure>.
+L<Encode>,
+L<Error::Pure>,
+L<Readonly>.
 
 =head1 SEE ALSO
 
@@ -418,11 +430,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2005-2015 Michal Špaček
+ © 2005-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
